@@ -813,6 +813,34 @@ void KCalculator::keyPressEvent(QKeyEvent *e) {
 	if (e->key() == Qt::Key_Control) {
 		emit switchShowAccels(true);
 	}
+
+	// Workaround for bug #283521
+	// Unfortunately adding multiple shortcuts (A, Shift+A) to pushbuttons
+	// does not work properly, so we handle the A-F keypresses with shift in Hex mode here
+	if (hexRadio->isChecked() && e->modifiers() & Qt::ShiftModifier) {
+		switch (e->key()) {
+		case Qt::Key_A:
+			pbA->animateClick();
+			break;
+		case Qt::Key_B:
+			pbB->animateClick();
+			break;
+		case Qt::Key_C:
+			pbC->animateClick();
+			break;
+		case Qt::Key_D:
+			pbD->animateClick();
+			break;
+		case Qt::Key_E:
+			pbE->animateClick();
+			break;
+		case Qt::Key_F:
+			pbF->animateClick();
+			break;
+		default:
+			break;
+		}
+	}
 }
 
 //------------------------------------------------------------------------------
@@ -2074,9 +2102,40 @@ void KCalculator::setColors() {
 
 	calc_display->changeSettings();
 
+	const QColor numFontColor(KCalcSettings::numberFontsColor());
+	for (int i = 0; i < 10; ++i) {
+		qobject_cast<KCalcButton*>((num_button_group_->button(i)))->setTextColor(numFontColor);
+	}
+
+	const QColor funcFontColor(KCalcSettings::functionFontsColor());
+	foreach(QAbstractButton *btn, function_button_list_) {
+		qobject_cast<KCalcButton*>(btn)->setTextColor(funcFontColor);
+	}
+
+	const QColor statFontColor(KCalcSettings::statFontsColor());
+	foreach(QAbstractButton *btn, stat_buttons_) {
+		qobject_cast<KCalcButton*>(btn)->setTextColor(statFontColor);
+	}
+
+	const QColor hexFontColor(KCalcSettings::hexFontsColor());
+	for (int i = 10; i < 16; ++i) {
+		qobject_cast<KCalcButton*>((num_button_group_->button(i)))->setTextColor(hexFontColor);
+	}
+
+	const QColor memFontColor(KCalcSettings::memoryFontsColor());
+	foreach(QAbstractButton *btn, mem_button_list_) {
+		qobject_cast<KCalcButton*>(btn)->setTextColor(memFontColor);
+	}
+
+	const QColor opFontColor(KCalcSettings::operationFontsColor());
+	foreach(QAbstractButton *btn, operation_button_list_) {
+		qobject_cast<KCalcButton*>(btn)->setTextColor(opFontColor);
+	}
+
 	KColorScheme schemeButtons(QPalette::Active, KColorScheme::Button);
 	const QColor defaultColor = schemeButtons.background().color();
 
+	// Do not apply style sheets when using default background colors, see bug 237513
 	if (KCalcSettings::numberButtonsColor()           == defaultColor
 			&& KCalcSettings::functionButtonsColor()  == defaultColor
 			&& KCalcSettings::statButtonsColor()      == defaultColor
@@ -2100,7 +2159,7 @@ void KCalculator::setColors() {
 
 	const QColor statPal(KCalcSettings::statButtonsColor());
 	foreach(QAbstractButton *btn, stat_buttons_) {
-	btn->setStyleSheet(sheet.arg(statPal.name()));
+		btn->setStyleSheet(sheet.arg(statPal.name()));
 	}
 
 	const QColor hexPal(KCalcSettings::hexButtonsColor());
