@@ -30,7 +30,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QTimer>
 
 #include <knotification.h>
-#include <KLocalizedString>
 
 #include "kcalc_core.h"
 #include "kcalc_settings.h"
@@ -798,7 +797,7 @@ void KCalcDisplay::newCharacter(const QChar new_char) {
 			}
 			return;
 		}
-		// no break
+		Q_FALLTHROUGH();
 	case '9':
 	case '8':
 		if (num_base_ == NB_OCTAL) {
@@ -807,7 +806,7 @@ void KCalcDisplay::newCharacter(const QChar new_char) {
 			}
 			return;
 		}
-		// no break
+		Q_FALLTHROUGH();
 	case '7':
 	case '6':
 	case '5':
@@ -820,7 +819,7 @@ void KCalcDisplay::newCharacter(const QChar new_char) {
 			}
 			return;
 		}
-		// no break
+		Q_FALLTHROUGH();
 	case '1':
 	case '0':
 		break;
@@ -997,7 +996,7 @@ void KCalcDisplay::paintEvent(QPaintEvent *) {
 	painter.setFont(fnt);
 	
 	QFontMetrics fm(fnt);
-	const uint w = fm.width(QStringLiteral("________"));
+        const uint w = fm.boundingRect(QStringLiteral("________")).width();
 	const uint h = fm.height();
 
 	for (int n = 0; n < NUM_STATUS_TEXT; ++n) {
